aboutsummaryrefslogtreecommitdiffstats
path: root/examples/charts/lineandbar.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/charts/lineandbar.py')
-rw-r--r--examples/charts/lineandbar.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/charts/lineandbar.py b/examples/charts/lineandbar.py
index 0a29aa786..e06298e63 100644
--- a/examples/charts/lineandbar.py
+++ b/examples/charts/lineandbar.py
@@ -39,13 +39,13 @@
##
#############################################################################
"""PySide2 port of the line/bar example from Qt v5.x"""
import sys
-from PySide2.QtCore import QPoint, Qt
-from PySide2.QtGui import QPainter
-from PySide2.QtWidgets import QMainWindow, QApplication
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import QPoint, Qt
+from PySide6.QtGui import QPainter
+from PySide6.QtWidgets import QMainWindow, QApplication
+from PySide6.QtCharts import QtCharts
class TestChart(QMainWindow):
@@ -39,13 +39,13 @@
##
#############################################################################
-"""PySide2 port of the line/bar example from Qt v5.x"""
+"""PySide6 port of the line/bar example from Qt v5.x"""
import sys